@@ -1,6 +1,6 @@
 package Statocles::Page::Document;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::Document::VERSION = '0.017';
+$Statocles::Page::Document::VERSION = '0.018';
 use Statocles::Class;
 with 'Statocles::Page';
 use Text::Markdown;
@@ -19,6 +19,13 @@ has document => (
 );
 
 
+has tags => (
+    is => 'ro',
+    isa => ArrayRef[HashRef],
+    default => sub { [] },
+);
+
+
 sub content {
     my ( $self ) = @_;
     return $self->markdown->markdown( $self->document->content );
@@ -52,7 +59,7 @@ Statocles::Page::Document - Render documents into HTML
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 DESCRIPTION
 
@@ -68,6 +75,14 @@ The publish date/time of this page. A L<Time::Piece> object.
 
 The L<document|Statocles::Document> this page will render.
 
+=head2 tags
+
+The tag links for this document. An array of link hashes with the following
+keys:
+
+    title   - The title of the link
+    href    - The page of the link
+
 =head1 METHODS
 
 =head2 content
